translate.filters.checks.StandardUnitChecker

Package translate :: Package filters :: Module checks :: Class StandardUnitChecker |
[hide private]
[frames] | no frames]

# Class StandardUnitChecker

source code

The standard checks for common checks on translation units.

Instance Methods | [hide private]
isfuzzy(self, unit) Check if the unit has been marked fuzzy. | source code
isreview(self, unit) Check if the unit has been marked review. | source code
nplurals(self, unit) Checks for the correct number of noun forms for plural translations. | source code
hassuggestion(self, unit) Checks if there is at least one suggested translation for this unit. | source code
Inherited from `UnitChecker`: `__init__`, `filteraccelerators`, `filteraccelerators_by_list`, `filtervariables`, `filterwordswithpunctuation`, `filterxml`, `getfilters`, `removevariables`, `run_filters`, `run_test`, `setconfig`, `setsuggestionstore` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `UnitChecker`: `preconditions`

Properties | [hide private]
Inherited from `object`: `__class__`